pub struct AlignmentSegment {
pub start: i32,
pub end: i32,
pub center: i32,
pub score: f64,
pub skip_forward: i32,
pub skip_backward: i32,
pub pair: Option<usize>,
pub number: i32,
}Expand description
An aligned segment region.
Replaces the C Segment struct which uses raw pointer-based pairing.
Here, the paired segment is referenced by an optional index into the
segment collection.
Fields
start: i32end: i32center: i32score: f64skip_forward: i32skip_backward: i32pair: Option<usize>Index of the paired segment, if any.
number: i32Trait Implementations
Sourceimpl Clone for AlignmentSegment
impl Clone for AlignmentSegment
Sourcefn clone(&self) -> AlignmentSegment
fn clone(&self) -> AlignmentSegment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AlignmentSegment
impl Debug for AlignmentSegment
Sourceimpl Default for AlignmentSegment
impl Default for AlignmentSegment
Sourcefn default() -> AlignmentSegment
fn default() -> AlignmentSegment
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for AlignmentSegment
impl PartialEq for AlignmentSegment
impl StructuralPartialEq for AlignmentSegment